@@ -207,6 +207,10 @@ namespace SoftWire
 		OperandREF(const char *ref)
 		{
 			type = Operand::IMM;
+			baseReg = Encoding::REG_UNKNOWN;
+			indexReg = Encoding::REG_UNKNOWN;
+			scale = 0;
+			displacement = 0;
 			reference = ref;
 		}
 
@@ -1216,8 +1220,8 @@ namespace SoftWire
 	{
 		OperandREF returnReg;
 
-		returnReg.baseReg = ref1.baseReg;
-		returnReg.indexReg = ref2.indexReg;
+		returnReg.baseReg = ref1.reg;
+		returnReg.indexReg = ref2.reg;
 		returnReg.scale = 1;
 		returnReg.displacement = ref1.displacement + ref2.displacement;
 
